@@ -2,8 +2,8 @@ import argparse, os, re
 from datetime import date, datetime
 from tkinter import filedialog
 from typing import Dict, List, Tuple, Type
-from records import STROKES, RECORD_TYPES, MeetRecord, RelayNameRecord, TeamIDRecord, IndividualEventRecord, SplitsRecord, IndividualInformationRecord, RelayEventRecord
-from time1 import Time
+from sdif_toolkit.records import STROKES, RECORD_TYPES, MeetRecord, RelayNameRecord, TeamIDRecord, IndividualEventRecord, SplitsRecord, IndividualInformationRecord, RelayEventRecord
+from sdif_toolkit.time import Time
 from pyodbc import connect
 
 RESULT_TYPES = {
